import request from '@/utils/request'

// 查询培训视频列表
export function listBusTrainingVideo(query) {
  return request({
    url: '/manage/busTrainingVideo/list',
    method: 'get',
    params: query
  })
}

// 统计培训视频列表
export function findBusTrainingVideo(query) {
  return request({
    url: '/manage/busTrainingVideo/findGroupByLevel',
    method: 'get',
    params: query
  })
}

// 查询培训视频详细
export function getBusTrainingVideo(id) {
  return request({
    url: '/manage/busTrainingVideo/' + id,
    method: 'get'
  })
}

// 新增培训视频
export function addBusTrainingVideo(data) {
  return request({
    url: '/manage/busTrainingVideo',
    method: 'post',
    data: data
  })
}

// 修改培训视频
export function updateBusTrainingVideo(data) {
  return request({
    url: '/manage/busTrainingVideo',
    method: 'put',
    data: data
  })
}

// 删除培训视频
export function delBusTrainingVideo(id) {
  return request({
    url: '/manage/busTrainingVideo/' + id,
    method: 'delete'
  })
}
